@@ -17,9 +17,6 @@ function mkvenv {
     $venv/bin/pip install $pip
 }
 
-# PROJECTS is a list of projects that we're testing
-PROJECTS=$*
-
 # BASE should be a directory with a subdir called "new" and in that
 #      dir, there should be a git repository for every entry in PROJECTS
 BASE=${BASE:-/opt/stack}
@@ -27,11 +24,11 @@ BASE=${BASE:-/opt/stack}
 REPODIR=${REPODIR:-$BASE/new}
 
 # TODO: Figure out how to get this on to the box properly
-sudo apt-get install -y --force-yes libxml2-dev libxslt-dev libmysqlclient-dev libpq-dev libnspr4-dev pkg-config libsqlite3-dev libzmq-dev libffi-dev
+sudo apt-get install -y --force-yes libxml2-dev libxslt-dev libmysqlclient-dev libpq-dev libnspr4-dev pkg-config libsqlite3-dev libzmq-dev libffi-dev libldap2-dev libsasl2-dev
 
-tmpdir=`mktemp -d`
+tmpdir=$(mktemp -d)
 
-whoami=`whoami`
+whoami=$(whoami)
 tmpdownload=$tmpdir/download
 mkdir -p $tmpdownload
 
@@ -40,9 +37,11 @@ mkdir -p $pypidir
 
 jeepybvenv=$tmpdir/jeepyb
 
+sudo touch $HOME/pip.log
+sudo chown $USER $HOME/pip.log
+
 rm -f ~/.pip/pip.conf ~/.pydistutils.cfg
 mkdir -p ~/.pip
-
 cat <<EOF > ~/.pip/pip.conf
 [global]
 log = $HOME/pip.log
@@ -64,6 +63,9 @@ mirrors:
     output: $pypidir
 EOF
 
+# PROJECTS is a list of projects that we're testing
+PROJECTS=$*
+
 pbrsdistdir=$tmpdir/pbrsdist
 git clone $REPODIR/pbr $pbrsdistdir
 cd $pbrsdistdir
@@ -77,6 +79,8 @@ $jeepybvenv/bin/python setup.py sdist -d $tmpdownload/pip/openstack
 
 $jeepybvenv/bin/run-mirror -b remotes/origin/master --verbose -c $tmpdir/mirror.yaml --no-download
 
+find $pypidir
+
 # Make pypi thing
 pypiurl=file://$pypidir
 
@@ -139,7 +143,7 @@ projectdir=$tmpdir/projects
 mkdir -p $projectdir
 
 for PROJECT in $PROJECTS ; do
-    SHORT_PROJECT=`basename $PROJECT`
+    SHORT_PROJECT=$(basename $PROJECT)
     if ! grep 'pbr' $REPODIR/$SHORT_PROJECT/requirements.txt >/dev/null 2>&1
     then
         # project doesn't use pbr
@@ -154,6 +158,13 @@ for PROJECT in $PROJECTS ; do
         continue
     fi
     shortprojectdir=$projectdir/$SHORT_PROJECT
+    sudo chown -R $USER $REPODIR/$SHORT_PROJECT
+    (cd $REPODIR/requirements && python update.py $REPODIR/$SHORT_PROJECT)
+    pushd $REPODIR/$SHORT_PROJECT
+    if ! git diff --quiet ; then
+        git commit -a -m'Update requirements'
+    fi
+    popd
     git clone $REPODIR/$SHORT_PROJECT $shortprojectdir
 
     sdistvenv=$tmpdir/sdist
